# coding: utf-8

"""
    PirlPay API

    The PirlPay API for automated payment processing  # noqa: E501

    OpenAPI spec version: v1
    Contact: support@pirl.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pirlpay
from pirlpay.subscription_transaction import SubscriptionTransaction  # noqa: E501
from pirlpay.rest import ApiException


class TestSubscriptionTransaction(unittest.TestCase):
    """SubscriptionTransaction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSubscriptionTransaction(self):
        """Test SubscriptionTransaction"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pirlpay.models.subscription_transaction.SubscriptionTransaction()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
